"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SEOHeadComponent = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactHelmet = _interopRequireDefault(require("react-helmet"));

var _ldJson = require("../util/seo/ldJson");

var _links = require("../util/seo/links");

var _metaTags = require("../util/seo/metaTags");

/**
 * Component for rendering SEO content in the document's head
 * Note: props passed to SEOHead should *not* be html-escaped because this is handled by Helmet
 * @see https://github.com/nfl/react-helmet
 * @param {String} baseUrl Base url of the page (protocol + hostname).
 * @param {String} imageUrl An image url that will be applied to the link tag, og:image meta tag, etc.
 * @param {Array} ldJson Array containing json-ld objects. These are usually generated by helper functions in src/util/seoHelper.js.
 * @param {String} localCode The current localeCode.
 * @param {String} forcedLocaleCode The current group locale code.
 * @param {String} ogDescription A special description for the Open Graph og:description meta tag. If this isn't provided pageDescription is used.
 * @param {String} ogTitle A special title for the Open Graph og:title meta tag. If this isn't provided pageTitle is used.
 * @param {String} pageDescription The page description, for example -- Upcoming Events for NY Tech in New York City
 * @param {String} pageKeywords A comma-separated string of keywords, for example -- 'upcoming events,ny-tech,ny,technology,group,club,event,community,local,networking,meet,sharing'
 * @param {Array} pageMeta Optional meta tag data, for example -- [{name: 'yandex', value: 12345},{name: 'bing', value: 12345}]
 * @param {String} pageTitle Content for the page's title tag
 * @param {Boolean} robots Instructs search engines whether or not we'd like them to crawl the pages and its links
 * @param {String} forcedRobotsContent overrides robots content when is not empty
 * @param {String} route The current route
 * @param {Boolean} isGenerateAlternateLinks Defines if we need to generate alternate link tags for the page
 * @module SEOHead
 */
var SEOHeadComponent = function SEOHeadComponent(_ref) {
  var baseUrl = _ref.baseUrl,
      imageUrl = _ref.imageUrl,
      ldJson = _ref.ldJson,
      localeCode = _ref.localeCode,
      forcedLocaleCode = _ref.forcedLocaleCode,
      ogDescription = _ref.ogDescription,
      ogTitle = _ref.ogTitle,
      pageDescription = _ref.pageDescription,
      pageKeywords = _ref.pageKeywords,
      pageMeta = _ref.pageMeta,
      pageTitle = _ref.pageTitle,
      robots = _ref.robots,
      forcedRobotsContent = _ref.forcedRobotsContent,
      route = _ref.route,
      isGenerateAlternateLinks = _ref.isGenerateAlternateLinks;
  var metaData = (0, _metaTags.generateMetaData)({
    appPath: "meetup:/".concat(route),
    baseUrl: baseUrl,
    pageDescription: pageDescription,
    imageUrl: imageUrl,
    localeCode: localeCode,
    pageKeywords: pageKeywords,
    ogTitle: ogTitle,
    ogDescription: ogDescription,
    route: route,
    pageTitle: pageTitle
  });
  var metaTags = (0, _metaTags.generateMetaTags)([].concat((0, _toConsumableArray2.default)(metaData), (0, _toConsumableArray2.default)(pageMeta)));
  var canonicalUrlLinkTags = (0, _links.generateCanonicalUrlLinkTags)(baseUrl, localeCode, route, isGenerateAlternateLinks, forcedLocaleCode);
  var ldJsonTags = ldJson.map(function (jsonObj, index) {
    return (// eslint-disable-next-line react/no-array-index-key
      _react.default.createElement("script", {
        type: "application/ld+json",
        key: "ldjson-".concat(index)
      }, JSON.stringify(jsonObj))
    );
  });

  var getRobotsContent = function getRobotsContent(robots, forcedRobotsContent) {
    if (forcedRobotsContent) {
      return forcedRobotsContent;
    }

    return robots ? 'index, follow' : 'noindex, nofollow';
  };

  return _react.default.createElement(_reactHelmet.default, {
    defaultTitle: "Meetup",
    titleTemplate: "%s | Meetup"
  }, _react.default.createElement("title", null, pageTitle), _react.default.createElement("link", {
    rel: "image_src",
    href: imageUrl
  }), _react.default.createElement("meta", {
    name: "robots",
    content: getRobotsContent(robots, forcedRobotsContent)
  }), metaTags, canonicalUrlLinkTags, ldJsonTags);
};

exports.SEOHeadComponent = SEOHeadComponent;
SEOHeadComponent.propTypes = {
  baseUrl: _propTypes.default.string.isRequired,
  imageUrl: _propTypes.default.string,
  ldJson: _propTypes.default.array,
  localeCode: _propTypes.default.string,
  ogTitle: _propTypes.default.string,
  ogDescription: _propTypes.default.string,
  pageDescription: _propTypes.default.string,
  pageKeywords: _propTypes.default.string,
  pageMeta: _propTypes.default.array,
  pageTitle: _propTypes.default.string,
  robots: _propTypes.default.bool,
  route: _propTypes.default.string.isRequired,
  isGenerateAlternateLinks: _propTypes.default.bool
};
SEOHeadComponent.defaultProps = {
  pageMeta: [],
  pageTitle: _ldJson.DEFAULT_TITLE,
  imageUrl: _metaTags.DEFAULT_IMAGE_URL,
  ldJson: [],
  localeCode: 'en-US',
  robots: true,
  isGenerateAlternateLinks: true
};
var _default = SEOHeadComponent;
exports.default = _default;
//# sourceMappingURL=SEOHead.js.map